const fs = require("fs");
const _ = require("lodash");

const conf_file = "etc/conf.json";
let conf = {};

module.exports = {
    name: 'conf',
    actions: {
        get(ctx) {
            if (ctx.params.path) {
                if (ctx.params.key) {
                    return _.get(conf, ctx.params.path)[ctx.params.key];
                } else {
                    return _.get(conf, ctx.params.path);
                }
            } else {
                return conf[ctx.params.key];
            }
        },
        set(ctx) {
            if (ctx.params.path) {
                if (!_.isObject(_.get(conf, ctx.params.path))) {
                    _.set(conf, ctx.params.path, {});
                }
                _.get(conf, ctx.params.path)[ctx.params.key] = ctx.params.value;
            } else {
                conf[ctx.params.key] = ctx.params.value;
            }
            return ctx.params.value;
        },
        unset(ctx) {
            if (ctx.params.path) {
                let p = _.get(conf, ctx.params.path);
                if (p) {
                    delete p[ctx.params.key];
                    if (_.isEmpty(_.keys(p))) {
                        _.unset(conf, ctx.params.path);
                    }
                }
            } else {
                delete conf[ctx.params.key];
            }
            return ctx.params;
        },
        all(ctx) {
            return conf;
        },
        save(ctx) {
            fs.writeFileSync("etc/conf.json", JSON.stringify(conf, null, "  "));
        }
    },
    async started() {
        try {
            conf = JSON.parse(fs.readFileSync(conf_file) + "");
            this.logger.info(`loaded conf_file, file = ${conf_file}`);
        } catch (err) {
            this.logger.err(`load conf_file error, file = ${conf_file}, err = ${err}`);
        }
    }
};
